{%- filter replace(':art:', '🎨') %}
{%- filter replace(':zap:', '⚡️') %}
{%- filter replace(':fire:', '🔥') %}
{%- filter replace(':bug:', '🐛') %}
{%- filter replace(':ambulance:', '🚑️') %}
{%- filter replace(':sparkles:', '✨') %}
{%- filter replace(':memo:', '📝') %}
{%- filter replace(':rocket:', '🚀') %}
{%- filter replace(':tada:', '🎉') %}
{%- filter replace(':white_check_mark:', '✅') %}
{%- filter replace(':lock:', '🔒️') %}
{%- filter replace(':closed_lock_with_key:', '🔐') %}
{%- filter replace(':bookmark:', '🔖') %}
{%- filter replace(':rotating_light:', '🚨') %}
{%- filter replace(':construction:', '🚧') %}
{%- filter replace(':green_heart:', '💚') %}
{%- filter replace(':arrow_down:', '⬇️') %}
{%- filter replace(':arrow_up:', '⬆️') %}
{%- filter replace(':pushpin:', '📌') %}
{%- filter replace(':construction_worker:', '👷') %}
{%- filter replace(':chart_with_upwards_trend:', '📈') %}
{%- filter replace(':recycle:', '♻️') %}
{%- filter replace(':heavy_plus_sign:', '➕') %}
{%- filter replace(':heavy_minus_sign:', '➖') %}
{%- filter replace(':wrench:', '🔧') %}
{%- filter replace(':hammer:', '🔨') %}
{%- filter replace(':globe_with_meridians:', '🌐') %}
{%- filter replace(':pencil2:', '✏️') %}
{%- filter replace(':poop:', '💩') %}
{%- filter replace(':rewind:', '⏪️') %}
{%- filter replace(':twisted_rightwards_arrows:', '🔀') %}
{%- filter replace(':package:', '📦️') %}
{%- filter replace(':alien:', '👽️') %}
{%- filter replace(':truck:', '🚚') %}
{%- filter replace(':page_facing_up:', '📄') %}
{%- filter replace(':boom:', '💥') %}
{%- filter replace(':bento:', '🍱') %}
{%- filter replace(':wheelchair:', '♿️') %}
{%- filter replace(':bulb:', '💡') %}
{%- filter replace(':beers:', '🍻') %}
{%- filter replace(':speech_balloon:', '💬') %}
{%- filter replace(':card_file_box:', '🗃️') %}
{%- filter replace(':loud_sound:', '🔊') %}
{%- filter replace(':mute:', '🔇') %}
{%- filter replace(':busts_in_silhouette:', '👥') %}
{%- filter replace(':children_crossing:', '🚸') %}
{%- filter replace(':building_construction:', '🏗️') %}
{%- filter replace(':clown_face:', '🤡') %}
{%- filter replace(':egg:', '🥚') %}
{%- filter replace(':see_no_evil:', '🙈') %}
{%- filter replace(':camera_flash:', '📸') %}
{%- filter replace(':alembic:', '⚗️') %}
{%- filter replace(':mag:', '🔍️') %}
{%- filter replace(':label:', '🏷️') %}
{%- filter replace(':seedling:', '🌱') %}
{%- filter replace(':triangular_flag_on_post:', '🚩') %}
{%- filter replace(':goal_net:', '🥅') %}
{%- filter replace(':dizzy:', '💫') %}
{%- filter replace(':wastebasket:', '🗑️') %}
{%- filter replace(':passport_control:', '🛂') %}
{%- filter replace(':adhesive_bandage:', '🩹') %}
{%- filter replace(':monocle_face:', '🧐') %}
{%- filter replace(':coffin:', '⚰️') %}
{%- filter replace(':test_tube:', '🧪') %}
{%- filter replace(':necktie:', '👔') %}
{%- filter replace(':stethoscope:', '🩺') %}
{%- filter replace(':bricks:', '🧱') %}
{%- filter replace(':technologist:', '🧑‍💻') %}
{%- filter replace(':money_with_wings:', '💸') %}
{%- filter replace(':thread:', '🧵') %}
{%- filter replace(':safety_vest:', '🦺') %}
{%- if type_ in [':bug:', 'BUG', 'fix'] %}
### :bug: Fixed Bugs
{%- elif type_ in [':memo:', 'DOC', 'docs'] %}
### :memo: Updated Documentation
{%- elif type_ in [':sparkles:', 'FEAT', 'feat'] %}
### :sparkles: Implemented Features
{%- elif type_ in [':zap:', 'BENCH', 'perf'] %}
### :sparkles: Improved Performance
{%- elif type_ in [':construction_worker:', 'BLD', 'ci'] %}
### :construction_worker: Updated Continuous Integration
{%- elif type_ in [':ambulance:'] %}
### :ambulance: Hotfixed Issues
{%- elif type_ in [':fire:'] %}
### :fire: Deleted Code or Files
{%- elif type_ in [':pencil2:'] %}
### :pencil2: Corrected Typos
{%- elif type_ in [':pushpin:'] %}
### :pushpin: Pinned Dependencies
{%- elif type_ in [':arrow_up:'] %}
### :arrow_up: Upgraded Dependencies
{%- elif type_ in [':arrow_down:'] %}
### :arrow_down: Downgraded Dependencies
{%- elif type_ in [':heavy_plus_sign:'] %}
### :heavy_plus_sign: Added Dependencies
{%- elif type_ in [':heavy_minus_sign:'] %}
### :heavy_minus_sign: Removed Dependencies
{%- elif type_ in [':children_crossing:'] %}
### :children_crossing: Improved Usability
{%- elif type_ in [':rotating_light:'] %}
### :rotating_light: Ran Linters
{%- elif type_ in [':hammer:'] %}
### :hammer: Updated Scripts
{%- elif type_ in [':wrench:'] %}
### :hammer: Updated Configuration
{%- elif type_ in [':wastebasket:'] %}
### :wastebasket: Deprecated Code
{%- else %}
### {{ type_ | capitalize }}
{% endif %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}